@@ -25,8 +25,9 @@ import os
 import sys
 import tempfile
 from collections import OrderedDict
-from importlib.metadata import entry_points
+from importlib.metadata import EntryPoint, entry_points
 from pathlib import Path
+from typing import Iterable
 
 try:
     from importlib.resources import files as impr_files  # type: ignore
@@ -123,10 +124,10 @@ def get_config_path_safe():
     return config_path
 
 
-def get_entry_points_config_dirs(name, include_config_path=True):
+def get_entry_points_config_dirs(group_name: str, include_config_path: bool = True) -> list[str]:
     """Get the config directories for all entry points of given name."""
-    dirs = []
-    for entry_point in cached_entry_points().get(name, []):
+    dirs: list[str] = []
+    for entry_point in cached_entry_point(group_name):
         module = _entry_point_module(entry_point)
         new_dir = str(impr_files(module) / "etc")
         if not dirs or dirs[-1] != new_dir:
@@ -137,12 +138,21 @@ def get_entry_points_config_dirs(name, include_config_path=True):
 
 
 @cache
-def cached_entry_points():
-    """Return entry_points.
+def cached_entry_point(group_name: str) -> Iterable[EntryPoint]:
+    """Return entry_point for specified ``group``.
+
+    This is a dummy proxy to allow caching and provide compatibility between
+    versions of Python and importlib_metadata.
 
-    This is a dummy proxy to allow caching.
     """
-    return entry_points()
+    try:
+        # mypy in pre-commit currently checks for Python 3.8 compatibility
+        # this line is for Python 3.10+ so it will fail checks
+        return entry_points(group=group_name)  # type: ignore
+    except TypeError:
+        # Python <3.10
+        entry_points_list = entry_points()
+        return entry_points_list.get(group_name, [])
 
 
 def _entry_point_module(entry_point):
