@@ -17,7 +17,6 @@
 
 import logging
 import os
-import warnings
 from collections import namedtuple
 from functools import wraps
 from numbers import Number
@@ -126,18 +125,6 @@ def using_map_blocks(func):
     return on_dask_array(wrapper)
 
 
-def crefl_scaling(img, **kwargs):
-    """Apply non-linear stretch used by CREFL-based RGBs."""
-    LOG.debug("Applying the crefl_scaling")
-    warnings.warn(
-        "'crefl_scaling' is deprecated, use 'piecewise_linear_stretch' instead.",
-        DeprecationWarning,
-        stacklevel=2
-    )
-    img.data.data = img.data.data / 100
-    return piecewise_linear_stretch(img, xp=kwargs['idx'], fp=kwargs['sc'], reference_scale_factor=255)
-
-
 def piecewise_linear_stretch(
         img: XRImage,
         xp: ArrayLike,
