@@ -32,12 +32,13 @@ import xarray as xr
 from pyproj import Proj
 from pyresample import geometry
 
-from satpy import CHUNK_SIZE
 from satpy.dataset import DataQuery
 from satpy.readers.file_handlers import BaseFileHandler
+from satpy.utils import get_legacy_chunk_size
 
 LOG = logging.getLogger(__name__)
 
+CHUNK_SIZE = get_legacy_chunk_size()
 
 CF_UNITS = {
     'none': '1',
